@@ -51,6 +51,9 @@ def main(args=None):
             "Search installed games to find the APPID\n"
             "$ protontricks -s GAME_NAME\n"
             "\n"
+            "List all installed games\n"
+            "$ protontricks -l\n"
+            "\n"
             "Use Protontricks GUI to select the game\n"
             "$ protontricks --gui\n"
             "\n"
@@ -84,6 +87,10 @@ def main(args=None):
     parser.add_argument(
         "-s", "--search", type=str, dest="search", nargs="+",
         required=False, help="Search for game(s) with the given name")
+    parser.add_argument(
+        "-l", "--list", action="store_true", dest="list", default=False,
+        help="List all apps"
+    )
     parser.add_argument(
         "-c", "--command", type=str, dest="command",
         required=False,
@@ -97,7 +104,7 @@ def main(args=None):
         "--no-runtime", action="store_true", default=False,
         help="Disable Steam Runtime")
     parser.add_argument(
-        "--no-bwrap", action="store_true", default=False,
+        "--no-bwrap", action="store_true", default=None,
         help="Disable bwrap containerization when using Steam Runtime"
     )
     parser.add_argument(
@@ -138,23 +145,29 @@ def main(args=None):
         exit_with_error(error, args.no_term)
 
     do_command = bool(args.command)
-    do_search = bool(args.search)
+    do_list_apps = bool(args.search) or bool(args.list)
     do_gui = bool(args.gui)
     do_winetricks = bool(args.appid and args.winetricks_command)
 
-    use_bwrap = not bool(args.no_bwrap)
+    # Set 'use_bwrap' to opposite of args.no_bwrap if it was provided.
+    # If not, keep it as None and determine the correct value to use later
+    # once we've determined whether the selected Steam Runtime is a bwrap-based
+    # one.
+    use_bwrap = (
+        not bool(args.no_bwrap) if args.no_bwrap in (True, False) else None
+    )
     start_background_wineserver = (
         args.background_wineserver
         if args.background_wineserver is not None
         else use_bwrap
     )
 
-    if not do_command and not do_search and not do_gui and not do_winetricks:
+    if not do_command and not do_list_apps and not do_gui and not do_winetricks:
         parser.print_help()
         return
 
     # Don't allow more than one action
-    if sum([do_search, do_gui, do_winetricks, do_command]) != 1:
+    if sum([do_list_apps, do_gui, do_winetricks, do_command]) != 1:
         print("Only one action can be performed at a time.")
         parser.print_help()
         return
@@ -263,14 +276,19 @@ def main(args=None):
         )
 
         return
-    # Perform a search
-    elif args.search:
-        # Search for games
-        search_query = " ".join(args.search)
-        matching_apps = [
-            app for app in steam_apps
-            if app.is_windows_app and app.name_contains(search_query)
-        ]
+    # List apps (either all or using a search)
+    elif do_list_apps:
+        if args.list:
+            matching_apps = [
+                app for app in steam_apps if app.is_windows_app
+            ]
+        else:
+            # Search for games
+            search_query = " ".join(args.search)
+            matching_apps = [
+                app for app in steam_apps
+                if app.is_windows_app and app.name_contains(search_query)
+            ]
 
         if matching_apps:
             matching_games = "\n".join([
